==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/order/orders_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	orders_edit.lang.inc.php 2019-04-05
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2019 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'EDIT_ADDED_PRODUCT'            => 'Artikel wurde zur Bestellung hinzugefügt.',
    'EDIT_ADDED_PRODUCT_OPTION'     => 'Artikeloption wurde zur Bestellung hinzugefügt.',
    'EDIT_ADDED_TRACING_NUMBER'     => 'Sendungsnummer wurde zur Bestellung hinzugefügt.',
    'EDIT_CHANGED_ADDRESS'          => 'Anschrift wurde geändert.',
    'EDIT_CHANGED_LANGUAGE'         => 'Sprache wurde geändert.',
    'EDIT_CHANGED_OT_ENTRY'         => 'Eintrag in der Bestellzusammenfassung wurde geändert.',
    'EDIT_CHANGED_PAYMENT_METHOD'   => 'Zahlungsweise wurde geändert.',
    'EDIT_CHANGED_PRODUCT'          => 'Artikel wurde geändert.',
    'EDIT_CHANGED_PRODUCT_OPTION'   => 'Artikeloption wurde geändert.',
    'EDIT_CHANGED_PRODUCT_PROPERTY' => 'Artikeleigenschaft wurde geändert.',
    'EDIT_CHANGED_SHIPPING_METHOD'  => 'Versandweise wurde geändert.',
    'EDIT_DELETED_OT_ENTRY'         => 'Eintrag in der Bestellzusammenfassung wurde gelöscht.',
    'EDIT_DELETED_PRODUCT'          => 'Artikel wurde gelöscht.',
    'EDIT_DELETED_PRODUCT_OPTION'   => 'Artikeloption wurde gelöscht.',
    'EDIT_RECALCULATED_ORDER'       => 'Bestellzusammenfassung wurde neu berechnet.',
    'ERROR_ARGUMENT_EXCEPTION'      => 'Die Eingabe in einem der Eingabefelder entspricht nicht dem Auswahlmöglichkeiten!',
    'ERROR_LENGTH_EXCEPTION'        => 'Die Eingabe in einem der Eingabefelder ist zu lang!',
    'ERROR_PRAEFIX'                 => 'Fehler im Abschnitt',
    'ERROR_VALUE_EXCEPTION'         => 'Die Eingabe in einem der Eingabefelder entspricht nicht dem erwarteten Format (z. B. Ganzzahlig oder Zeichenkette)!',
    'ERROR_ORDER_NOT_FOUND'         => 'Die Bestellung konnte nicht gefunden werden',
    'HEADING_CANCELLATION_WARNING'  => 'Falls Sie eine Rechnung aus dieser Bestellung stornieren möchten, stornieren Sie diese bitte bevor Sie diese Bestellung bearbeiten.',
    'HEADING_WARNING'               => 'Bitte beachten Sie, dass das Modul zur manuellen Bestellnachbearbeitung unter Umständen nicht korrekt arbeitet. Bitte überprüfen Sie alle errechneten Werte auf deren Korrektheit.',
    'MENU_CUSTOMER_DATA'            => 'Adress- und Kundendaten',
    'MENU_ORDER_DATA'               => 'Versandarten, Zahlungsweisen und Summen',
    'MENU_PRODUCT_DATA'             => 'Artikel und Artikeloptionen',
    'IMAGE_EDIT_ADDRESS'            => 'Adressen bearbeiten oder einfügen',
    'IMAGE_EDIT_OTHER'              => 'Versandarten, Zahlungsweisen, Gutscheine usw. bearbeiten oder einfügen',
    'IMAGE_EDIT_PRODUCTS'           => 'Artikel und Optionen bearbeiten oder einfügen',
    'TABLE_HEADING'                 => 'Bestelldaten bearbeiten',
    'TABLE_HEADING_ORDER'           => 'Bestellung Nr: ',
    'TEXT_ACTUAL'                   => 'aktuell',
    'TEXT_ADDITIONAL_INFO'          => 'Zusatzinformationen',
    'TEXT_BILLING_ADDRESS'          => 'Rechnungsadresse',
    'TEXT_CITY'                     => 'Stadt',
    'TEXT_COMPANY'                  => 'Firma',
    'TEXT_COUNTRY'                  => 'Land',
    'TEXT_COUPON_CODE'              => 'neuer Couponcode',
    'TEXT_CURRENCIES'               => 'Währungen',
    'TEXT_CUSTOMER_EMAIL'           => 'E-Mail',
    'TEXT_CUSTOMER_GROUP'           => 'Kundengruppe in der Bestellung',
    'TEXT_CUSTOMER_TELEPHONE'       => 'Telefon',
    'TEXT_CUSTOMER_UST'             => 'USt-IdNr.',
    'TEXT_CUT_CREDIT_BALANCE'       => 'Guthaben reduzieren',
    'TEXT_EDIT_ADDRESS'             => 'Adressdaten und Kundendaten bearbeiten und einfügen.',
    'TEXT_EDIT_ADDRESS_SUCCESS'     => 'Adressänderung wurde gespeichert.',
    'TEXT_EDIT_GIFT'                => 'Gutscheine und Rabatt bearbeiten oder einfügen',
    'TEXT_EDIT_OTHER'               => 'Versandarten, Zahlungsweisen, Sprachen usw. bearbeiten und einfügen.',
    'TEXT_EDIT_PRODUCTS'            => 'Artikel und Artikeloptionen bearbeiten und einfügen.',
    'TEXT_FINAL'                    => 'Gesamt',
    'TEXT_FIRSTNAME'                => 'Vorname',
    'TEXT_INVOICE_ADDRESS'          => 'Kundenadresse',
    'TEXT_LANGUAGE'                 => 'Sprache',
    'TEXT_LASTNAME'                 => 'Nachname',
    'TEXT_NAME'                     => 'Name',
    'TEXT_NEW'                      => 'neu',
    'TEXT_NO_SHIPPING'              => 'Kein Versand',
    'TEXT_ORDER_TOTAL'              => 'Zusammenfassung',
    'TEXT_PAYMENT'                  => 'Zahlungsweise',
    'TEXT_PRICE'                    => 'Kosten: ',
    'TEXT_PRICE_PREFIX'             => 'Preis-Präfix',
    'TEXT_PRODUCT'                  => 'Artikel',
    'TEXT_PRODUCTS_MODEL'           => 'Art.Nr.',
    'TEXT_PRODUCT_ID'               => 'pID',
    'TEXT_PRODUCT_OPTION'           => 'Artikelmerkmal',
    'TEXT_PRODUCT_OPTION_VALUE'     => 'Optionswert',
    'TEXT_PRODUCT_SEARCH'           => 'Artikelsuche',
    'TEXT_QUANTITY'                 => 'Anzahl',
    'TEXT_QUANTITY_UNIT'            => 'Einheit',
    'TEXT_REDEEMED_COUPON'          => 'eingelöster Coupon',
    'TEXT_SAVE'                     => 'Speichern',
    'TEXT_SAVE_ORDER'               => 'Nachbearbeitung beenden und Bestellung neu berechnen.',
    'TEXT_SHIPPING'                 => 'Versandart',
    'TEXT_SHIPPING_ADDRESS'         => 'Versandadresse',
    'TEXT_SMALL_NETTO'              => ' (netto)',
    'TEXT_STATE'                    => 'Bundesland',
    'TEXT_STREET'                   => 'Straße',
    'TEXT_HOUSE_NUMBER'             => 'Nr.',
    'TEXT_SUBURB'                   => 'Stadtteil',
    'TEXT_TAX'                      => 'MwSt.',
    'TEXT_UPDATE_STOCK'             => 'Lagerbestand anhand der Anzahl verändern',
    'TEXT_ZIP'                      => 'PLZ',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/order/orders_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	orders_edit.lang.inc.php 2025-03-28
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2025 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'EDIT_ADDED_PRODUCT'            => 'Artikel wurde zur Bestellung hinzugefügt.',
    'EDIT_ADDED_PRODUCT_OPTION'     => 'Artikeloption wurde zur Bestellung hinzugefügt.',
    'EDIT_ADDED_TRACING_NUMBER'     => 'Sendungsnummer wurde zur Bestellung hinzugefügt.',
    'EDIT_CHANGED_ADDRESS'          => 'Anschrift wurde geändert.',
    'EDIT_CHANGED_LANGUAGE'         => 'Sprache wurde geändert.',
    'EDIT_CHANGED_OT_ENTRY'         => 'Eintrag in der Bestellzusammenfassung wurde geändert.',
    'EDIT_CHANGED_PAYMENT_METHOD'   => 'Zahlungsweise wurde geändert.',
    'EDIT_CHANGED_PRODUCT'          => 'Artikel wurde geändert.',
    'EDIT_CHANGED_PRODUCT_OPTION'   => 'Artikeloption wurde geändert.',
    'EDIT_CHANGED_PRODUCT_PROPERTY' => 'Artikelvariante wurde geändert.',
    'EDIT_CHANGED_SHIPPING_METHOD'  => 'Versandweise wurde geändert.',
    'EDIT_DELETED_OT_ENTRY'         => 'Eintrag in der Bestellzusammenfassung wurde gelöscht.',
    'EDIT_DELETED_PRODUCT'          => 'Artikel wurde gelöscht.',
    'EDIT_DELETED_PRODUCT_OPTION'   => 'Artikeloption wurde gelöscht.',
    'EDIT_RECALCULATED_ORDER'       => 'Bestellzusammenfassung wurde neu berechnet.',
    'ERROR_ARGUMENT_EXCEPTION'      => 'Die Eingabe in einem der Eingabefelder entspricht nicht dem Auswahlmöglichkeiten!',
    'ERROR_LENGTH_EXCEPTION'        => 'Die Eingabe in einem der Eingabefelder ist zu lang!',
    'ERROR_PRAEFIX'                 => 'Fehler im Abschnitt',
    'ERROR_VALUE_EXCEPTION'         => 'Die Eingabe in einem der Eingabefelder entspricht nicht dem erwarteten Format (z. B. Ganzzahlig oder Zeichenkette)!',
    'ERROR_ORDER_NOT_FOUND'         => 'Die Bestellung konnte nicht gefunden werden',
    'HEADING_CANCELLATION_WARNING'  => 'Falls du eine Rechnung aus dieser Bestellung stornieren möchtest, storniere diese bitte bevor du diese Bestellung bearbeitest.',
    'HEADING_WARNING'               => 'Bitte beachte, dass das Modul zur manuellen Bestellnachbearbeitung unter Umständen nicht korrekt arbeitet. Bitte überprüfe alle errechneten Werte auf deren Korrektheit.',
    'MENU_CUSTOMER_DATA'            => 'Adress- und Kundendaten',
    'MENU_ORDER_DATA'               => 'Versandarten, Zahlungsweisen und Summen',
    'MENU_PRODUCT_DATA'             => 'Artikel und Artikeloptionen',
    'IMAGE_EDIT_ADDRESS'            => 'Adressen bearbeiten oder einfügen',
    'IMAGE_EDIT_OTHER'              => 'Versandarten, Zahlungsweisen, Gutscheine usw. bearbeiten oder einfügen',
    'IMAGE_EDIT_PRODUCTS'           => 'Artikel und Optionen bearbeiten oder einfügen',
    'TABLE_HEADING'                 => 'Bestelldaten bearbeiten',
    'TABLE_HEADING_ORDER'           => 'Bestellung Nr: ',
    'TEXT_ACTUAL'                   => 'aktuell',
    'TEXT_ADDITIONAL_INFO'          => 'Zusatzinformationen',
    'TEXT_BILLING_ADDRESS'          => 'Rechnungsadresse',
    'TEXT_CITY'                     => 'Stadt',
    'TEXT_COMPANY'                  => 'Firma',
    'TEXT_COUNTRY'                  => 'Land',
    'TEXT_COUPON_CODE'              => 'neuer Couponcode',
    'TEXT_CURRENCIES'               => 'Währungen',
    'TEXT_CUSTOMER_EMAIL'           => 'E-Mail',
    'TEXT_CUSTOMER_GROUP'           => 'Kundengruppe in der Bestellung',
    'TEXT_CUSTOMER_TELEPHONE'       => 'Telefon',
    'TEXT_CUSTOMER_UST'             => 'USt-IdNr.',
    'TEXT_CUT_CREDIT_BALANCE'       => 'Guthaben reduzieren',
    'TEXT_EDIT_ADDRESS'             => 'Adressdaten und Kundendaten bearbeiten und einfügen.',
    'TEXT_EDIT_ADDRESS_SUCCESS'     => 'Adressänderung wurde gespeichert.',
    'TEXT_EDIT_GIFT'                => 'Gutscheine und Rabatt bearbeiten oder einfügen',
    'TEXT_EDIT_OTHER'               => 'Versandarten, Zahlungsweisen, Sprachen usw. bearbeiten und einfügen.',
    'TEXT_EDIT_PRODUCTS'            => 'Artikel und Artikeloptionen bearbeiten und einfügen.',
    'TEXT_FINAL'                    => 'Gesamt',
    'TEXT_FIRSTNAME'                => 'Vorname',
    'TEXT_INVOICE_ADDRESS'          => 'Kundenadresse',
    'TEXT_LANGUAGE'                 => 'Sprache',
    'TEXT_LASTNAME'                 => 'Nachname',
    'TEXT_NAME'                     => 'Name',
    'TEXT_NEW'                      => 'neu',
    'TEXT_NO_SHIPPING'              => 'Kein Versand',
    'TEXT_ORDER_TOTAL'              => 'Zusammenfassung',
    'TEXT_PAYMENT'                  => 'Zahlungsweise',
    'TEXT_PRICE'                    => 'Kosten: ',
    'TEXT_PRICE_PREFIX'             => 'Preis-Präfix',
    'TEXT_PRODUCT'                  => 'Artikel',
    'TEXT_PRODUCTS_MODEL'           => 'Art.Nr.',
    'TEXT_PRODUCT_ID'               => 'pID',
    'TEXT_PRODUCT_OPTION'           => 'Artikelmerkmal',
    'TEXT_PRODUCT_OPTION_VALUE'     => 'Optionswert',
    'TEXT_PRODUCT_SEARCH'           => 'Artikelsuche',
    'TEXT_QUANTITY'                 => 'Anzahl',
    'TEXT_QUANTITY_UNIT'            => 'Einheit',
    'TEXT_REDEEMED_COUPON'          => 'eingelöster Coupon',
    'TEXT_SAVE'                     => 'Speichern',
    'TEXT_SAVE_ORDER'               => 'Nachbearbeitung beenden und Bestellung neu berechnen.',
    'TEXT_SHIPPING'                 => 'Versandart',
    'TEXT_SHIPPING_ADDRESS'         => 'Versandadresse',
    'TEXT_SMALL_NETTO'              => ' (netto)',
    'TEXT_STATE'                    => 'Bundesland',
    'TEXT_STREET'                   => 'Straße',
    'TEXT_HOUSE_NUMBER'             => 'Nr.',
    'TEXT_SUBURB'                   => 'Stadtteil',
    'TEXT_TAX'                      => 'MwSt.',
    'TEXT_UPDATE_STOCK'             => 'Lagerbestand anhand der Anzahl verändern',
    'TEXT_ZIP'                      => 'Postleitzahl',
];
